@@ -138,7 +138,7 @@ async def check_valid_urls_parallel(urls, log_file_path, interval, timeout, cont
             print(f'Saved log at: {log_file_path}')
             print(f'Saved contents at: {content_subdir}')
 
-async def main():
+def main():
     parser = argparse.ArgumentParser(description="Generate URLs with specified regex pattern and check their validity.")
     parser.usage = f"{sys.argv[0]} " + "[{gen,check,match}]  [-h] [-o OUTPUT_PATH] [-p PATTERN] [-c COUNT] [-l LIMIT] [-t TIMEOUT] [-I INTERVAL] [-s {natural,asc,desc,random}] [-d] [input_path [input_path ...]]"
     parser.add_argument('input_path', nargs='*', help='Input path for URLs. If not provided, read from stdin.')
@@ -157,7 +157,7 @@ async def main():
     temp_file = f'{temp_dir}/{ts}'
 
     if "gen" in args.mode:
-        await generate_urls(args.pattern, temp_file, args.count, args.limit, args.sort, args.interval)
+        asyncio.run(generate_urls(args.pattern, temp_file, args.count, args.limit, args.sort, args.interval))
         print(f"Generated URLs are saved to: {temp_file}")
 
     if "check" in args.mode:
@@ -172,10 +172,10 @@ async def main():
             urls = args.input_path
         else:
             urls = sys.stdin.read().splitlines()
-        await check_valid_urls_parallel(urls, log_file, args.interval, args.timeout, content_subdir, args.download)
+        asyncio.run(check_valid_urls_parallel(urls, log_file, args.interval, args.timeout, content_subdir, args.download))
 
     if "match" in args.mode:
         match_urls(args.input_path, args.pattern)
 
 if __name__ == "__main__":
-    asyncio.run(main())
+    main()
